@@ -1,4 +1,4 @@
-//@line 39 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/preferences/advanced.js"
+//@line 39 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -19,14 +19,15 @@ var gAdvancedPane = {
       advancedPrefs.selectedTab = document.getElementById(extraArgs["advancedTab"]);
     } else {
       var preference = document.getElementById("browser.preferences.advanced.selectedTabIndex");
-      if (preference.value === null)
-        return;
-      advancedPrefs.selectedIndex = preference.value;
+      if (preference.value !== null)
+        advancedPrefs.selectedIndex = preference.value;
     }
 
+//@line 64 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
     this.updateAppUpdateItems();
     this.updateAutoItems();
     this.updateModeItems();
+//@line 68 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
   },
 
@@ -126,7 +127,7 @@ var gAdvancedPane = {
   readCacheSize: function ()
   {
     var preference = document.getElementById("browser.cache.disk.capacity");
-    return preference.value / 1000;
+    return preference.value / 1024;
   },
 
   /**
@@ -137,7 +138,7 @@ var gAdvancedPane = {
   {
     var cacheSize = document.getElementById("cacheSize");
     var intValue = parseInt(cacheSize.value, 10);
-    return isNaN(intValue) ? 0 : intValue * 1000;
+    return isNaN(intValue) ? 0 : intValue * 1024;
   },
 
   /**
@@ -177,15 +178,24 @@ var gAdvancedPane = {
   },
 
   // XXX: duplicated in browser.js
-  _getOfflineAppUsage: function (host)
+  _getOfflineAppUsage: function (host, groups)
   {
-    var cacheService = Components.classes["@mozilla.org/network/cache-service;1"].
-                       getService(Components.interfaces.nsICacheService);
-    var cacheSession = cacheService.createSession("HTTP-offline",
-                                                  Components.interfaces.nsICache.STORE_OFFLINE,
-                                                  true).
-                       QueryInterface(Components.interfaces.nsIOfflineCacheSession);
-    var usage = cacheSession.getDomainUsage(host);
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    if (!groups) {
+      groups = cacheService.getGroups({});
+    }
+    var ios = Components.classes["@mozilla.org/network/io-service;1"].
+              getService(Components.interfaces.nsIIOService);
+
+    var usage = 0;
+    for (var i = 0; i < groups.length; i++) {
+      var uri = ios.newURI(groups[i], null, null);
+      if (uri.asciiHost == host) {
+        var cache = cacheService.getActiveCache(groups[i]);
+        usage += cache.usage;
+      }
+    }
 
     var storageManager = Components.classes["@mozilla.org/dom/storagemanager;1"].
                          getService(Components.interfaces.nsIDOMStorageManager);
@@ -207,6 +217,10 @@ var gAdvancedPane = {
       list.removeChild(list.firstChild);
     }
 
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    var groups = cacheService.getGroups({});
+
     var bundle = document.getElementById("bundlePreferences");
 
     var enumerator = pm.enumerator;
@@ -220,7 +234,7 @@ var gAdvancedPane = {
         row.className = "offlineapp";
         row.setAttribute("host", perm.host);
         var converted = DownloadUtils.
-                        convertByteUnits(this._getOfflineAppUsage(perm.host));
+                        convertByteUnits(this._getOfflineAppUsage(perm.host, groups));
         row.setAttribute("usage",
                          bundle.getFormattedString("offlineAppUsage",
                                                    converted));
@@ -261,14 +275,18 @@ var gAdvancedPane = {
       return;
 
     // clear offline cache entries
-    var cacheService = Components.classes["@mozilla.org/network/cache-service;1"]
-                       .getService(Components.interfaces.nsICacheService);
-    var cacheSession = cacheService.createSession("HTTP-offline",
-                                                  Components.interfaces.nsICache.STORE_OFFLINE,
-                                                  true)
-                       .QueryInterface(Components.interfaces.nsIOfflineCacheSession);
-    cacheSession.clearKeysOwnedByDomain(host);
-    cacheSession.evictUnownedEntries();
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    var ios = Components.classes["@mozilla.org/network/io-service;1"].
+              getService(Components.interfaces.nsIIOService);
+    var groups = cacheService.getGroups({});
+    for (var i = 0; i < groups.length; i++) {
+        var uri = ios.newURI(groups[i], null, null);
+        if (uri.asciiHost == host) {
+            var cache = cacheService.getActiveCache(groups[i]);
+            cache.discard();
+        }
+    }
 
     // send out an offline-app-removed signal.  The nsDOMStorage
     // service will clear DOM storage for this host.
@@ -343,6 +361,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
+//@line 402 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
   updateAppUpdateItems: function () 
   {
     var aus = 
@@ -389,18 +408,6 @@ var gAdvancedPane = {
     warnIncompatible.disabled = disable;
   },
 
-  /**
-   * The Extensions checkbox and button are disabled only if the enable Addon
-   * update preference is locked. 
-   */
-  updateAddonUpdateUI: function ()
-  {
-    var enabledPref = document.getElementById("extensions.update.enabled");
-    var enableAddonUpdate = document.getElementById("enableAddonUpdate");
-
-    enableAddonUpdate.disabled = enabledPref.locked;
-  },  
-
   /**
    * Stores the value of the app.update.mode preference, which is a tristate
    * integer preference.  We store the value here so that we can properly
@@ -451,6 +458,19 @@ var gAdvancedPane = {
                              .createInstance(Components.interfaces.nsIUpdatePrompt);
     prompter.showUpdateHistory(window);
   },
+//@line 499 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
+
+  /**
+   * The Extensions checkbox and button are disabled only if the enable Addon
+   * update preference is locked. 
+   */
+  updateAddonUpdateUI: function ()
+  {
+    var enabledPref = document.getElementById("extensions.update.enabled");
+    var enableAddonUpdate = document.getElementById("enableAddonUpdate");
+
+    enableAddonUpdate.disabled = enabledPref.locked;
+  },  
   
   // ENCRYPTION TAB
 
@@ -485,7 +505,7 @@ var gAdvancedPane = {
    */
   showCRLs: function ()
   {
-    document.documentElement.openWindow("Mozilla:CRLManager", 
+    document.documentElement.openWindow("mozilla:crlmanager", 
                                         "chrome://pippki/content/crlManager.xul",
                                         "", null);
   },
@@ -508,7 +528,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 549 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/preferences/advanced.js"
+//@line 569 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -554,5 +574,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 595 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/preferences/advanced.js"
+//@line 615 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/advanced.js"
 };
