@@ -1,16 +1,10 @@
-//@line 39 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/preferences/tabs.js"
+//@line 39 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/preferences/tabs.js"
 
 var gTabsPane = {
 
   /*
    * Preferences:
    *
-   * browser.link.open_external
-   * - determines where pages opened by external applications are opened:
-   *     0 opens such links in the default window,
-   *     1 opens such links in the most recent window or tab,
-   *     2 opens such links in a new window,
-   *     3 opens such links in a new tab
    * browser.link.open_newwindow
    * - determines where pages which would open in a new window are opened:
    *     0 opens such links in the default window,
@@ -34,26 +28,21 @@ var gTabsPane = {
   /**
    * Determines where a link which opens a new window will open.
    *
-   * @returns 2 if such links should be opened in new windows,
-   *          3 if such links should be opened in new tabs
+   * @returns |true| if such links should be opened in new tabs
    */
   readLinkTarget: function() {
-    var openExternal = document.getElementById("browser.link.open_external");
-    return openExternal.value != 2 ? 3 : 2;
+    var openNewWindow = document.getElementById("browser.link.open_newwindow");
+    return openNewWindow.value != 2;
   },
 
   /**
-   * Ensures that pages opened in new windows by web pages and pages opened by
-   * external applications both open in the same way (e.g. in a new tab, window,
-   * etc.).
+   * Determines where a link which opens a new window will open.
    *
    * @returns 2 if such links should be opened in new windows,
    *          3 if such links should be opened in new tabs
    */
   writeLinkTarget: function() {
     var linkTargeting = document.getElementById("linkTargeting");
-    document.getElementById("browser.link.open_newwindow").value = linkTargeting.value;
-    return linkTargeting.value;
+    return linkTargeting.checked ? 3 : 2;
   }
 };
-
