@@ -1,4 +1,4 @@
-//@line 40 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/search/content/engineManager.js"
+//@line 40 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/search/content/engineManager.js"
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
@@ -130,29 +130,20 @@ var gEngineManagerDialog = {
       var eduplicate = false;
 
       if (alias.value != "") {
-        var searchService = Cc["@mozilla.org/browser/search-service;1"].
-                            getService(Ci.nsIBrowserSearchService);
-        var engine = searchService.getEngineByAlias(alias.value);
+        try {
+          let bmserv = Cc["@mozilla.org/browser/nav-bookmarks-service;1"].
+                       getService(Ci.nsINavBookmarksService);
+          if (bmserv.getURIForKeyword(alias.value))
+            bduplicate = true;
+        } catch(ex) {}
 
-        if (engine) {
-          if (engine.name != selectedEngine.name)
+        // Check for duplicates in changes we haven't committed yet
+        let engines = gEngineView._engineStore.engines;
+        for each (let engine in engines) {
+          if (engine.alias == alias.value && 
+              engine.name != selectedEngine.name) {
             eduplicate = true;
-        } else {
-          try {
-            var bmserv = Cc["@mozilla.org/browser/nav-bookmarks-service;1"].
-                         getService(Ci.nsINavBookmarksService);
-            if (bmserv.getURIForKeyword(alias.value))
-              bduplicate = true;
-          } catch(ex) {}
-
-          // Check for duplicates in changes we haven't committed yet
-          var engines = gEngineView._engineStore.engines;
-          for each (var engine in engines) {
-            if (engine.alias == alias.value && 
-                engine.name != selectedEngine.name) {
-              eduplicate = true;
-              break;
-            }
+            break;
           }
         }
       }
