@@ -1,4 +1,4 @@
-//@line 39 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/web-panels.js"
+//@line 39 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/web-panels.js"
 
 const NS_ERROR_MODULE_NETWORK = 2152398848;
 const NS_NET_STATUS_READ_FROM = NS_ERROR_MODULE_NETWORK + 8;
@@ -78,7 +78,6 @@ function load()
                              null, null);
     }
 
-    gNavigatorBundle = document.getElementById("bundle_browser");
     gLoadFired = true;
 }
 
