@@ -1,4 +1,4 @@
-//@line 37 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 37 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
 
 const nsISupports            = Components.interfaces.nsISupports;
 
@@ -29,7 +29,7 @@ const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
 const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
 
-const NS_BINDING_ABORTED = 0x804b0002;
+const NS_BINDING_ABORTED = Components.results.NS_BINDING_ABORTED;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
 const NS_ERROR_ABORT = Components.results.NS_ERROR_ABORT;
 
@@ -100,6 +100,13 @@ function needHomepageOverride(prefb) {
                          .getService(nsIHttpProtocolHandler).misc;
 
   if (mstone != savedmstone) {
+    // Bug 462254. Previous releases had a default pref to suppress the EULA
+    // agreement if the platform's installer had already shown one. Now with
+    // about:rights we've removed the EULA stuff and default pref, but we need
+    // a way to make existing profiles retain the default that we removed.
+    if (savedmstone)
+      prefb.setBoolPref("browser.rights.3.shown", true);
+    
     prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
     return (savedmstone ? OVERRIDE_NEW_MSTONE : OVERRIDE_NEW_PROFILE);
   }
@@ -108,7 +115,7 @@ function needHomepageOverride(prefb) {
 }
 
 // Copies a pref override file into the user's profile pref-override folder,
-// and then tells the pref service to reload it's default prefs.
+// and then tells the pref service to reload its default prefs.
 function copyPrefOverride() {
   try {
     var fileLocator = Components.classes["@mozilla.org/file/directory_service;1"]
@@ -141,17 +148,60 @@ function copyPrefOverride() {
   }
 }
 
-function openWindow(parent, url, target, features, args) {
+// Flag used to indicate that the arguments to openWindow can be passed directly.
+const NO_EXTERNAL_URIS = 1;
+
+function openWindow(parent, url, target, features, args, noExternalArgs) {
   var wwatch = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                          .getService(nsIWindowWatcher);
 
-  var argstring;
-  if (args) {
-    argstring = Components.classes["@mozilla.org/supports-string;1"]
+  if (noExternalArgs == NO_EXTERNAL_URIS) {
+    // Just pass in the defaultArgs directly
+    var argstring;
+    if (args) {
+      argstring = Components.classes["@mozilla.org/supports-string;1"]
                             .createInstance(nsISupportsString);
-    argstring.data = args;
+      argstring.data = args;
+    }
+
+    return wwatch.openWindow(parent, url, target, features, argstring);
   }
-  return wwatch.openWindow(parent, url, target, features, argstring);
+  
+  // Pass an array to avoid the browser "|"-splitting behavior.
+  var argArray = Components.classes["@mozilla.org/supports-array;1"]
+                    .createInstance(Components.interfaces.nsISupportsArray);
+
+  // add args to the arguments array
+  var stringArgs = null;
+  if (args instanceof Array) // array
+    stringArgs = args;
+  else if (args) // string
+    stringArgs = [args];
+
+  if (stringArgs) {
+    // put the URIs into argArray
+    var uriArray = Components.classes["@mozilla.org/supports-array;1"]
+                       .createInstance(Components.interfaces.nsISupportsArray);
+    stringArgs.forEach(function (uri) {
+      var sstring = Components.classes["@mozilla.org/supports-string;1"]
+                              .createInstance(nsISupportsString);
+      sstring.data = uri;
+      uriArray.AppendElement(sstring);
+    });
+    argArray.AppendElement(uriArray);
+  } else {
+    argArray.AppendElement(null);
+  }
+
+  // Pass these as null to ensure that we always trigger the "single URL"
+  // behavior in browser.js's BrowserStartup (which handles the window
+  // arguments)
+  argArray.AppendElement(null); // charset
+  argArray.AppendElement(null); // referer
+  argArray.AppendElement(null); // postData
+  argArray.AppendElement(null); // allowThirdPartyFixup
+
+  return wwatch.openWindow(parent, url, target, features, argArray);
 }
 
 function openPreferences() {
@@ -172,29 +222,11 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 218 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
-
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
-  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                     .getService(Components.interfaces.nsIWindowMediator);
-
-//@line 225 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
-  var win = wm.getMostRecentWindow("navigator:browser", true);
-
-  // if we're lucky, this isn't a popup, and we can just return this
-  if (win && win.document.documentElement.getAttribute("chromehidden")) {
-    var windowList = wm.getEnumerator("navigator:browser", true);
-    // this is oldest to newest, so this gets a bit ugly
-    while (windowList.hasMoreElements()) {
-      var nextWin = windowList.getNext();
-      if (!nextWin.document.documentElement.getAttribute("chromehidden"))
-        win = nextWin;
-    }
-  }
-//@line 250 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
-
-  return win;
+  var browserGlue = Components.classes["@mozilla.org/browser/browserglue;1"]
+                              .getService(Components.interfaces.nsIBrowserGlue);
+  return browserGlue.getMostRecentBrowserWindow();
 }
 
 function doSearch(searchTerm, cmdLine) {
@@ -262,9 +294,10 @@ var nsBrowserContentHandler = {
   /* nsICommandLineHandler */
   handle : function bch_handle(cmdLine) {
     if (cmdLine.handleFlag("browser", false)) {
+      // Passing defaultArgs, so use NO_EXTERNAL_URIS
       openWindow(null, this.chromeURL, "_blank",
                  "chrome,dialog=no,all" + this.getFeatures(cmdLine),
-                 this.defaultArgs);
+                 this.defaultArgs, NO_EXTERNAL_URIS);
       cmdLine.preventDefault = true;
     }
 
@@ -325,9 +358,10 @@ var nsBrowserContentHandler = {
           if (remoteParams[0].toLowerCase() != "openbrowser")
             throw NS_ERROR_ABORT;
 
+          // Passing defaultArgs, so use NO_EXTERNAL_URIS
           openWindow(null, this.chromeURL, "_blank",
                      "chrome,dialog=no,all" + this.getFeatures(cmdLine),
-                     this.defaultArgs);
+                     this.defaultArgs, NO_EXTERNAL_URIS);
           break;
 
         default:
@@ -388,7 +422,7 @@ var nsBrowserContentHandler = {
         var netutil = Components.classes["@mozilla.org/network/util;1"]
                                 .getService(nsINetUtil);
         if (!netutil.URIChainHasFlags(uri, URI_INHERITS_SECURITY_CONTEXT)) {
-          openWindow(null, uri.spec, "_blank", features, "");
+          openWindow(null, uri.spec, "_blank", features);
           cmdLine.preventDefault = true;
         }
       }
@@ -409,7 +443,19 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 479 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+    var fileParam = cmdLine.handleFlagWithParam("file", false);
+    if (fileParam) {
+      var file = cmdLine.resolveFile(fileParam);
+      var ios = Components.classes["@mozilla.org/network/io-service;1"]
+                          .getService(Components.interfaces.nsIIOService);
+      var uri = ios.newFileURI(file);
+      openWindow(null, this.chromeURL, "_blank", 
+                 "chrome,dialog=no,all" + this.getFeatures(cmdLine),
+                 uri.spec);
+      cmdLine.preventDefault = true;
+    }
+
+//@line 506 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -618,13 +664,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 690 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 717 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 716 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 743 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -686,23 +732,19 @@ var nsDefaultCommandLineHandler = {
         }
       }
 
-      var speclist = [];
-      for (uri in urilist) {
-        if (shouldLoadURI(urilist[uri]))
-          speclist.push(urilist[uri].spec);
-      }
-
-      if (speclist.length) {
+      var URLlist = urilist.filter(shouldLoadURI).map(function (u) u.spec);
+      if (URLlist.length) {
         openWindow(null, nsBrowserContentHandler.chromeURL, "_blank",
                    "chrome,dialog=no,all" + nsBrowserContentHandler.getFeatures(cmdLine),
-                   speclist.join("|"));
+                   URLlist);
       }
 
     }
     else if (!cmdLine.preventDefault) {
+      // Passing defaultArgs, so use NO_EXTERNAL_URIS
       openWindow(null, nsBrowserContentHandler.chromeURL, "_blank",
                  "chrome,dialog=no,all" + nsBrowserContentHandler.getFeatures(cmdLine),
-                 nsBrowserContentHandler.defaultArgs);
+                 nsBrowserContentHandler.defaultArgs, NO_EXTERNAL_URIS);
     }
   },
 
@@ -783,9 +825,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 875 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 898 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 877 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 900 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
