@@ -1,4 +1,4 @@
-//@line 38 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/nsDefaultCLH.js"
+//@line 38 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/nsDefaultCLH.js"
 
 const nsISupports              = Components.interfaces.nsISupports;
 
@@ -78,6 +78,10 @@ var nsDefaultCLH = {
       dump(out + "\n");
       Components.utils.reportError(out);
     }
+    
+    if (cmdLine.handleFlag("silent", false)) {
+      cmdLine.preventDefault = true;
+    }
 
     if (cmdLine.preventDefault)
       return;
