@@ -1,4 +1,4 @@
-//@line 37 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
+//@line 37 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
 
 // We wastefully reload the same JS files across components.  This puts all
 // the common JS files used by safebrowsing and url-classifier into a
@@ -8,7 +8,7 @@ const Cc = Components.classes;
 const Ci = Components.interfaces;
 const G_GDEBUG = false;
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/lang.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/lang.js"
 
 
 /**
@@ -88,7 +88,7 @@ Function.prototype.inherits = function(parentCtor) {
   this.superClass_ = parentCtor.prototype;
   this.prototype = new tempCtor();
 }
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/preferences.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/preferences.js"
 
 
 // Class for manipulating preferences. Aside from wrapping the pref
@@ -317,9 +317,9 @@ G_PreferenceObserver.prototype.QueryInterface = function(iid) {
   throw Components.results.NS_ERROR_NO_INTERFACE;
 }
 
-//@line 38 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/debug.js"
+//@line 38 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/debug.js"
 
-//@line 868 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/debug.js"
+//@line 868 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/debug.js"
 
 // Stubs for the debugging aids scattered through this component.
 // They will be expanded if you compile yourself a debug build.
@@ -329,7 +329,7 @@ function G_Assert(who, condition, msg) { }
 function G_Error(who, msg) { }
 var G_debugService = { __noSuchMethod__: function() { } };
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/alarm.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/alarm.js"
 
 
 // An Alarm fires a callback after a certain amount of time, or at
@@ -475,7 +475,7 @@ G_ConditionalAlarm.prototype.notify = function(timer) {
     this.cancel();
   }
 }
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/cryptohasher.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/cryptohasher.js"
 
 
 // A very thin wrapper around nsICryptoHash. It's not strictly
@@ -617,7 +617,7 @@ G_CryptoHasher.prototype.toHex_ = function(str) {
   return hexrep.join('');
 }
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/observer.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/observer.js"
 
 
 // A couple of classes to simplify creating observers. 
@@ -717,7 +717,7 @@ G_ObserverServiceObserver.prototype.observe_ = function(subject, topic, data) {
     this.unregister();
 }
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/moz/protocol4.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/moz/protocol4.js"
 
 
 // A helper class that knows how to parse from and serialize to
@@ -793,7 +793,7 @@ G_Protocol4Parser.prototype.serialize = function(map) {
   return text;
 }
 
-//@line 53 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
+//@line 53 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
 
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
@@ -942,7 +942,7 @@ RequestBackoff.prototype.isErrorStatus = function(status) {
           HTTP_TEMPORARY_REDIRECT == status);
 }
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/url-crypto-key-manager.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/url-crypto-key-manager.js"
 
 
 // This file implements the tricky business of managing the keys for our 
@@ -1122,8 +1122,8 @@ PROT_UrlCryptoKeyManager.prototype.reKey = function() {
   G_Debug(this, "Attempting to re-key");
   // If the keyUrl isn't set, we don't do anything.
   if (!this.testing_ && this.keyUrl_) {
-    (new PROT_XMLFetcher()).get(this.keyUrl_,
-                                BindToObject(this.onGetKeyResponse, this));
+    this.fetcher_ = new PROT_XMLFetcher();
+    this.fetcher_.get(this.keyUrl_, BindToObject(this.onGetKeyResponse, this));
     this.updating_ = true;
 
     // Calculate the next time we're allowed to re-key.
@@ -1168,6 +1168,11 @@ PROT_UrlCryptoKeyManager.prototype.hasKey = function() {
   return this.clientKey_ != null && this.wrappedKey_ != null;
 }
 
+PROT_UrlCryptoKeyManager.prototype.unUrlSafe = function(key)
+{
+    return key ? key.replace("-", "+").replace("_", "/") : "";
+}
+
 /**
  * Set a new key and serialize it to disk.
  *
@@ -1183,7 +1188,7 @@ PROT_UrlCryptoKeyManager.prototype.replaceKey_ = function(clientKey,
     G_Debug(this, "Replacing " + this.clientKey_ + " with " + clientKey);
 
   this.clientKey_ = clientKey;
-  this.clientKeyArray_ = Array.map(atob(clientKey),
+  this.clientKeyArray_ = Array.map(atob(this.unUrlSafe(clientKey)),
                                    function(c) { return c.charCodeAt(0); });
   this.wrappedKey_ = wrappedKey;
 
@@ -1253,6 +1258,7 @@ PROT_UrlCryptoKeyManager.prototype.onGetKeyResponse = function(responseText) {
   var wrappedKey = response[this.WRAPPED_KEY_NAME];
 
   this.updating_ = false;
+  this.fetcher_ = null;
 
   if (response && clientKey && wrappedKey) {
     G_Debug(this, "Got new key from: " + responseText);
@@ -1323,8 +1329,15 @@ PROT_UrlCryptoKeyManager.prototype.maybeLoadOldKey = function() {
   }
 }
 
+PROT_UrlCryptoKeyManager.prototype.shutdown = function() {
+  if (this.fetcher_) {
+    this.fetcher_.cancel();
+    this.fetcher_ = null;
+  }
+}
 
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/content/xml-fetcher.js"
+
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/content/xml-fetcher.js"
 
 // A simple class that encapsulates a request. You'll notice the
 // style here is different from the rest of the extension; that's
@@ -1402,6 +1415,12 @@ PROT_XMLFetcher.prototype = {
     this._request.send(null);
   },
 
+  cancel: function() {
+    this._request.onreadystatechange = null;
+    this._request.abort();
+    this._request = null;
+  },
+
   /**
    * Called periodically by the request to indicate some state change. 4
    * means content has been received.
@@ -1518,7 +1537,7 @@ PROT_CookieStripper.prototype.QueryInterface = function(iid) {
   throw Components.results.NS_ERROR_NO_INTERFACE;
 }
 
-//@line 57 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
+//@line 57 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/url-classifier/src/nsUrlClassifierLib.js"
 
 // Expose this whole component.
 var lib = this;
